vehicle.c
changeset 2926 d503d725d7d4
parent 2916 8f1aa489701f
child 2932 16e9c72e32df
--- a/vehicle.c	Sun Jan 29 21:38:24 2006 +0000
+++ b/vehicle.c	Sun Jan 29 22:40:51 2006 +0000
@@ -2122,12 +2122,9 @@
 	SLE_CONDVARX(offsetof(Vehicle,u)+offsetof(VehicleRail,flags), SLE_UINT8, 2, 255),
 	SLE_CONDVARX(offsetof(Vehicle,u)+offsetof(VehicleRail,days_since_order_progr), SLE_UINT16, 2, 255),
 
-	// reserve extra space in savegame here. (currently 8 bytes)
-	SLE_CONDARR(NullStruct, null, SLE_FILE_U8 | SLE_VAR_NULL, 8, 2, 255),
-
-	SLE_CONDREFX(offsetof(Vehicle,u)+offsetof(VehicleRail,other_multiheaded_part), REF_VEHICLE, 2, 19),	// added with 17.1, but was blank since 2. Removed in 20
-	// reserve extra space in savegame here. (currently 3 bytes)
-	SLE_CONDARR(NullStruct,null,SLE_FILE_U8 | SLE_VAR_NULL, 3, 2, 255),
+	SLE_CONDARR(NullStruct, null, SLE_FILE_U8 | SLE_VAR_NULL, 2, 2, 19),
+	// reserve extra space in savegame here. (currently 11 bytes)
+	SLE_CONDARR(NullStruct, null, SLE_FILE_U8 | SLE_VAR_NULL, 11, 2, 255),
 
 	SLE_END()
 };